"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.componentGenerator = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const component_1 = require("../actions/component");
const messages_1 = require("../messages");
const validators_1 = require("../validators");
/**
 * Foundation UI Component Generator
 */
exports.componentGenerator = {
    description: (0, messages_1.generatorDescription)('Generate a custom foundation-ui base component.'),
    prompts(inquirer, prevAns = {}) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const designSystemsDirectories = (0, utils_1.getDesignSystemsDirectories)();
            const { name, designSystemChoices, force } = yield inquirer.prompt([
                {
                    type: 'input',
                    name: 'name',
                    message: 'What is your custom foundation component name?',
                    default: 'notional-input',
                },
                {
                    type: 'checkbox',
                    message: 'Which design systems should this be included in?',
                    name: 'designSystemChoices',
                    choices: (0, utils_1.mapToCheckboxChoices)(designSystemsDirectories),
                    default: (0, utils_1.mapToNames)(designSystemsDirectories),
                    validate: validators_1.atLeastOne,
                },
                {
                    type: 'confirm',
                    message: 'Overwrite existing files?',
                    name: 'force',
                    default: false,
                },
            ]);
            return {
                name,
                designSystemChoices,
                force,
            };
        });
    },
    actions: (answers) => (0, component_1.getAddComponentActions)({
        components: [answers.name],
        designSystemChoices: answers.designSystemChoices,
        force: answers.force,
        baseComponent: false,
    }),
};
